@@ -11,9 +11,10 @@ use cronos_program::state::InstructionData as CronosInstructionData;
 
 pub fn task_create(
     task_pda: PDA,
+    config: Pubkey,
     daemon: Pubkey,
     owner: Pubkey,
-    instruction: Instruction,
+    ix: Instruction,
     exec_at: i64,
     stop_at: i64,
     recurr: i64,
@@ -22,13 +23,14 @@ pub fn task_create(
         program_id: cronos_program::ID,
         accounts: vec![
             AccountMeta::new_readonly(sysvar::clock::ID, false),
+            AccountMeta::new_readonly(config, false),
             AccountMeta::new(daemon, false),
             AccountMeta::new(owner, true),
             AccountMeta::new(task_pda.0, false),
             AccountMeta::new_readonly(system_program::ID, false),
         ],
         data: cronos_program::instruction::TaskCreate {
-            instruction_data: CronosInstructionData::from(instruction),
+            ix: CronosInstructionData::from(ix),
             exec_at,
             stop_at,
             recurr,
